# Copyright 2015 Oliver Cope
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from .core import BasePlugin, TemplateEnvironment


class ChameleonPlugin(BasePlugin):
    def __init__(self, *args, **kwargs):
        from chameleon import PageTemplateLoader
        from chameleon.loader import TemplateLoader

        if (
            not kwargs
            and len(args) == 1
            and isinstance(args[0], TemplateLoader)
        ):
            self.loader = args[0]
        else:
            self.loader = PageTemplateLoader(*args, **kwargs)

    def render(self, template, data, stream):
        if stream:
            raise Exception("streaming not supported for Chameleon")
        return self.loader[template].render(**data)


class Chameleon(TemplateEnvironment):
    plugin_class = ChameleonPlugin
